==> eslint-config-scalify-0.0.6.tgz: package/rules/best-practices.js <==
// best-practices for writing Js code

module.exports =
{
	rules: {

        // Enforces return statements in callbacks of array’s methods
		'array-callback-return': 'error',

		// Enforce that class methods utilize this
		'class-methods-use-this': 'error',

		// Limit Cyclomatic Complexity
		'complexity': [ 'error', 5 ],

		// require return statements to either always or never specify values
		'consistent-return': 'error',

		// Require Following Curly Brace Conventions
		'curly': [ 'error', 'all' ],

		// Require Default Case in Switch Statements
		'default-case': 'error',

		// Require Dot Notation
		'dot-notation': 'error',

		// Require === and !==
		'eqeqeq': 'error',

		// Require Guarding for-in
		'guard-for-in': 'error',

		// Disallow lexical declarations in case/default clauses
		'no-case-declarations': 'error',

		// Disallow Regexs That Look Like Division
		'no-div-regex': 'off',

		// Disallow return before else
		'no-else-return': 'error',

		// Disallow empty functions
		'no-empty-function': 'error',

		// Disallow empty destructuring patterns
		'no-empty-pattern': 'off',

		// Disallow eval()
		'no-eval': 'error',

		// Disallow Extending of Native Objects
		'no-extend-native': 'error',

		// Disallow Case Statement Fallthrough
		'no-fallthrough': 'error',

		// Disallow Floating Decimals
		'no-floating-decimal': 'error',

		// Disallow assignment to native objects or read-only global variables
		'no-global-assign': 'off',

		// Disallow Implied eval()
		'no-implied-eval': 'off',

		// disallow this keywords outside of classes or class-like objects
		'no-invalid-this': 'off',

		// Disallow Unnecessary Nested Blocks
		'no-lone-blocks': 'error',

		// Disallow Functions in Loops
		'no-loop-func': 'error',

		// Disallow multiple spaces
		'no-multi-spaces': 'error',

		// Disallow Multiline Strings
		'no-multi-str': 'error',

		// Disallow Function Constructor
		'no-new-func': 'error',

		// Disallow new For Side Effects
		'no-new': 'error',

		// disallow octal literals
		'no-octal': 'error',

		// Disallow Reassignment of Function Parameters
		'no-param-reassign': 'error',

		// Disallow Redeclaring Variables
		'no-redeclare': 'error',

		// Disallow Assignment in return Statement
		'no-return-assign': 'error',

		// Disallow Self Assignment
		'no-self-assign': 'off',

		// Disallow Self Compare
		'no-self-compare': 'off',

		// Restrict what can be thrown as an exception
		'no-throw-literal': 'error',

		// Disallow unnecessary .call() and .apply().
		'no-useless-call': 'off',

		// disallow with statements
		'no-with': 'error',

		// Require Radix Parameter
		'radix': 'off',

		// Require or disallow Yoda Conditions
		'yoda': 'error'
	}
};

==> eslint-config-scalify-0.0.12.tgz: package/rules/best-practices.js <==
// best-practices for writing Js code

module.exports =
{
	rules: {

        // Enforces return statements in callbacks of array’s methods
		'array-callback-return': 'error',

		// Enforce that class methods utilize this
		'class-methods-use-this': 'warn',

		// Limit Cyclomatic Complexity
		'complexity': [ 'error', 5 ],

		// require return statements to either always or never specify values
		'consistent-return': 'error',

		// Require Following Curly Brace Conventions
		'curly': [ 'error', 'all' ],

		// Require Default Case in Switch Statements
		'default-case': 'error',

		// Require Dot Notation
		'dot-notation': 'error',

		// Require === and !==
		'eqeqeq': 'error',

		// Require Guarding for-in
		'guard-for-in': 'error',

		// Disallow lexical declarations in case/default clauses
		'no-case-declarations': 'error',

		// Disallow Regexs That Look Like Division
		'no-div-regex': 'off',

		// Disallow return before else
		'no-else-return': 'error',

		// Disallow empty functions
		'no-empty-function': 'error',

		// Disallow empty destructuring patterns
		'no-empty-pattern': 'off',

		// Disallow eval()
		'no-eval': 'error',

		// Disallow Extending of Native Objects
		'no-extend-native': 'error',

		// Disallow Case Statement Fallthrough
		'no-fallthrough': 'error',

		// Disallow Floating Decimals
		'no-floating-decimal': 'error',

		// Disallow assignment to native objects or read-only global variables
		'no-global-assign': 'off',

		// Disallow Implied eval()
		'no-implied-eval': 'off',

		// disallow this keywords outside of classes or class-like objects
		'no-invalid-this': 'off',

		// Disallow Unnecessary Nested Blocks
		'no-lone-blocks': 'error',

		// Disallow Functions in Loops
		'no-loop-func': 'error',

		// Disallow multiple spaces
		'no-multi-spaces': 'error',

		// Disallow Multiline Strings
		'no-multi-str': 'error',

		// Disallow Function Constructor
		'no-new-func': 'error',

		// Disallow new For Side Effects
		'no-new': 'error',

		// disallow octal literals
		'no-octal': 'error',

		// Disallow Reassignment of Function Parameters
		'no-param-reassign': 'error',

		// Disallow Redeclaring Variables
		'no-redeclare': 'error',

		// Disallow Assignment in return Statement
		'no-return-assign': 'error',

		// Disallow Self Assignment
		'no-self-assign': 'off',

		// Disallow Self Compare
		'no-self-compare': 'off',

		// Restrict what can be thrown as an exception
		'no-throw-literal': 'error',

		// Disallow unnecessary .call() and .apply().
		'no-useless-call': 'off',

		// disallow with statements
		'no-with': 'error',

		// Require Radix Parameter
		'radix': 'off',

		// Require or disallow Yoda Conditions
		'yoda': 'error'
	}
};
